==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "การอัปโหลดได้ล้มเหลว"

, "Putting files in this folder is not allowed!"
: "ไม่อนุญาตให้ใส่ไฟล์ในแฟ้มนี้!"

, "Filemanager"
: "ตัวจัดการไฟล์"

, "Save locally"
: ""

, "Tags"
: "ป้ายกำกับ"

, "Name"
: "ชื่อ"

, "Size"
: "ขนาด"

, "Contenttype"
: "ประเภทเนื้อหา"

, "Folder, Folders"
: [
  "แฟ้มเอกสาร"

]
, "Creation Time"
: "เวลาที่สร้างขึ้น"

, "Created By"
: "สร้าง โดย"

, "Last Modified Time"
: "เวลาที่ปรับปรุงครั้งล่าสุด"

, "Last Modified By"
: "ปรับปรุงครั้งล่าสุด โดย"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "อัปโหลด"

, "Open Data Safe"
: ""

, "Folder Up"
: ""

, "Close Data Safe"
: ""

, "Node Download Links"
: ""

, "Url"
: "Url"

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "ไม่สามารถให้บริการได้"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: ""

, "Files already exists"
: "ไฟล์นี้มีอยู่แล้ว"

, "Do you want to replace the following file(s)?"
: "คุณต้องการแทนที่ไฟล์(s) ต่อไปนี้?"

, "Failure on create folder"
: "เกิดความล้มเหลวขณะสร้างแฟ้มเอกสาร"

, "Item with this name already exists!"
: "รายการกับชื่อนี้มีอยู่แล้ว!"

, "Revision"
: "การแก้ไขปรับปรุง"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "เส้นทาง"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "สร้างแฟ้มเอกสาร"

, "New Folder"
: "แฟ้มเอกสารใหม่"

, "Please enter the name of the new folder:"
: "กรุณาใส่ชื่อของแฟ้มใหม่:"

, "No {0} added"
: "ไม่ได้เพิ่ม {0} "

, "You have to supply a {0} name!"
: ""

, "Edit Properties"
: "จัดการ คุณสมบัติต่าง ๆ "

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "กรุณาใส่ชื่อใหม่ของ {0}:"

, "Not renamed {0}"
: ""

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "ลบ"

, "Do you really want to delete the following files?"
: "คุณแน่ใจว่าต้องการลบไฟล์ต่อไปนี้?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: "ตีพิมพ์"

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: "แฟ้มได้ถูกตีพิมพ์อย่างประสบความสำเร็จ"

, "File has been published successfully"
: "ไฟล์ได้ถูกตีพิมพ์อย่างถูกต้อง"

, "File, Files"
: [
  ""

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: ""

, "Moving data .. {0}"
: ""

, "Please wait"
: "กรุณารอ"

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "Type"
: "ประเภท"

, "Description"
: "การอธิบาย"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: "เอาบันทึกออก"

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: "ลิงค์สาธารณะ"

, "Not yet indexed"
: ""

, "Modified By"
: ""

, "Last Modified"
: ""

, "Enter description"
: "ใส่ คำอธิบาย"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: "สร้าง ลิงค์สาธารณะ"

, "Creating new Download Link..."
: "กำลังสร้าง ลิงค์ดาวน์โหลดใหม่..."

, "Deleting Download Links..."
: "กำลังลบ ลิงค์ดาวน์โหลด..."

, "Deleting Download Link..."
: ""

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "จัดการแฟ้มเอกสารที่ใช้ร่วมกัน"

, "Create new shared folders"
: "สร้างแฟ้มเอกสารที่ใช้ร่วมกันใหม่"

, "Manage anonymous download links"
: ""

, "Allow to see, add and delete download links of files and folders"
: "อนุญาตให้เห็น เพิ่ม และลบลิงค์ที่ดาวน์โหลดของไฟล์และแฟ้มต่าง ๆ ได้"

, "Destination is a Subfolder"
: "เป้าหมายคือแฟ้มรอง"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: "จุดมุ่งหมายมีหนทางเดียวกัน"

, "The destination has the same path the source has. No action has been performed."
: "จุดมุ่งหมายมีหนทางเดียวกันกับแหล่งที่มา ไม่ต้องแสดงใดๆทั้งสิ้น"

, "My folders"
: "แฟ้มเอกสารของฉัน"

, "Shared folders"
: "แฟ้มเอกสารที่ใช้ร่วมกัน"

, "Other users folders"
: "แฟ้มเอกสารของผู้ใช้อื่น"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: "แฟ้มเอกสาร"

, "File"
: ""

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "ชื่อ"

, "Size"
: "ขนาด"

, "Last Modified"
: ""

, "Description"
: "การอธิบาย"

, "Folder, Folders"
: [
  "แฟ้มเอกสาร"

]
, "File, Files"
: [
  ""

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "เส้นทาง"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: "สร้าง ลิงค์สาธารณะ"

, "Remove record"
: "เอาบันทึกออก"

, "Creating new Download Link..."
: "กำลังสร้าง ลิงค์ดาวน์โหลดใหม่..."

, "Deleting Download Links..."
: "กำลังลบ ลิงค์ดาวน์โหลด..."

, "Deleting Download Link..."
: ""

, "Created By"
: "สร้าง โดย"

, "Creation Time"
: "เวลาที่สร้างขึ้น"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "เวลาที่ปรับปรุงครั้งล่าสุด"

, "Last Modified By"
: "ปรับปรุงครั้งล่าสุด โดย"

, "Revision"
: "การแก้ไขปรับปรุง"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "การอัปโหลดได้ล้มเหลว"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "ป้ายกำกับ"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "อัปโหลด"

, "Open Data Safe"
: ""

, "Folder Up"
: ""

, "Close Data Safe"
: ""

, "Filemanager"
: "ตัวจัดการไฟล์"

, "Save locally"
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: "ลิงค์สาธารณะ"

, "Type"
: "ประเภท"

, "Not yet indexed"
: ""

, "Modified By"
: ""

, "Enter description"
: "ใส่ คำอธิบาย"

, "Service Unavailable"
: "ไม่สามารถให้บริการได้"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: ""

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "คุณต้องการแทนที่ไฟล์(s) ต่อไปนี้?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "รายการกับชื่อนี้มีอยู่แล้ว!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: "ตีพิมพ์"

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: ""

, "Moving data .. {0}"
: ""

, "Please wait"
: "กรุณารอ"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "สร้างแฟ้มเอกสาร"

, "New Folder"
: "แฟ้มเอกสารใหม่"

, "Please enter the name of the new folder:"
: "กรุณาใส่ชื่อของแฟ้มใหม่:"

, "No {0} added"
: "ไม่ได้เพิ่ม {0} "

, "You have to supply a {0} name!"
: ""

, "Edit Properties"
: "จัดการ คุณสมบัติต่าง ๆ "

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "กรุณาใส่ชื่อใหม่ของ {0}:"

, "Not renamed {0}"
: ""

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "ลบ"

, "Do you really want to delete the following files?"
: "คุณแน่ใจว่าต้องการลบไฟล์ต่อไปนี้?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: "แฟ้มได้ถูกตีพิมพ์อย่างประสบความสำเร็จ"

, "File has been published successfully"
: "ไฟล์ได้ถูกตีพิมพ์อย่างถูกต้อง"

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "แฟ้มเอกสารของฉัน"

, "Shared folders"
: "แฟ้มเอกสารที่ใช้ร่วมกัน"

, "Other users folders"
: "แฟ้มเอกสารของผู้ใช้อื่น"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: "เป้าหมายคือแฟ้มรอง"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: "จุดมุ่งหมายมีหนทางเดียวกัน"

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "จัดการแฟ้มเอกสารที่ใช้ร่วมกัน"

, "Create new shared folders"
: "สร้างแฟ้มเอกสารที่ใช้ร่วมกันใหม่"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""








, "Folder"
: "แฟ้มเอกสาร"

, "File"
: ""

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
